#!/usr/bin/perl -w

################################################################################
#
# This perl script will look at the galleries DBs and image server to check that
# the uncropped and cropped tif files are up to date.
#                      
#  Copyright (c) 2010 Joseph Padfield <joseph.padfield@ng-london.org.uk>
#
#  ---------------------------------------------------------------------------
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   ---------------------------------------------------------------------------
#
#	This script has been developed in Version 8.10 of Unbuntu Linux 
#
#	In addition to perl you will also need to install the following packages:
#
#  # 
#
#	Plus any additional packages that these three rely on.
#		
################################################################################

use DBI;   
use POSIX qw(ceil floor sqrt);
use File::Basename;

require( "./header.pl" );

my $img = $ARGV[0];
my $tmpPyr = $img."-PYR.tif";
my $fname = $ARGV[1];

my @suffixlist = (
	".jpg", ".JPG", ".tif", ".TIF", ".BMP", ".bmp", ".jpeg", ".JPEG", 
	".png", ".v", ".gif", ".GIF", 
	".pdf", ".doc", ".DNG", ".raw", ".RAW", ".txt", ".FFF", ".ppt", ".PPT", "");
my $debug;
my $output;
my $fileFormat = '';
my $fileType = 0;

my ($name,$path,$suffix) = fileparse("$fname",@suffixlist);
$suffix = lc($suffix);

if ($suffix eq ".pdf" || $suffix eq ".doc" || $suffix eq ".dng" || 
		$suffix eq ".raw" || $suffix eq ".txt" || $suffix eq ".fff" || 
		$suffix eq ".ppt" || $suffix eq ".PPT" )
  {$fileType = 26;
	 $fileFormat = getFileFormatID ($suffix);}
elsif ($suffix) #Ignore .db and .DS_Store files Images
  {$fileType = 25;
	 $fileFormat = getFileFormatID ($suffix);}
else
  {
	my $wch = "identify $img";
	my $id = `$wch`;
	
	if( $id =~ /^$img[ ]([a-zA-Z]+)[ ]+.+/ ) 
		{$fileFormat = getFileFormatID ($suffix, ucfirst($1));
		 $fileType = 25;}
	}
  
my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
  $year += 1900;
  $mon = sprintf("%02.0f", $mon + 1);
  $mday = sprintf("%02.0f", $mday);
    
my $fileSize = -s "$img";
my $pixelWidth;
my $pixelHeight;
my $bitDepth;
my $pyrLevels;
my $targetpath = $data_folder."/project_files/$year/$mon/$mday/";
my $targetppath = $data_folder."/project_pyr/$year/$mon/$mday/";
my $targetfile = $targetpath.$name.$suffix;
my $targetpyramid = $targetppath.$name."-PYR.tif";
my $webpath = $web_folder."/files/$year/$mon/$mday/";
#my $webfile = "/files/$year/$mon/$mday/";

my $mkp = "mkdir -p \"$targetpath\"";  
my $mkpp = "mkdir -p \"$targetppath\"";  
my $mkwp = "mkdir -p \"$webpath\"";  

my $cmd1 = "./makePyr.sh \"$img\" \"$tmpPyr\"";
my $cmd2 = "mv \"$img\" \"$targetfile\"";
my $cmd3 = "mv \"$tmpPyr\" \"$targetpyramid\"";
my $cmd4 = "`chmod a-x \"$targetfile\"";
my $cmd5 = "ln -s \"$targetfile\" \"".$webpath.$name.$suffix."\"";

unless (-d "$targetpath")
  {$debug = `$mkp`;
   if (-d "$targetpath") {`chmod -R a+rw \"$targetpath\"`;}
  if ($debug) {$output .= $debug."\n"}}
unless (-d "$targetppath")
  {$debug = `$mkpp`;
   if (-d "$targetppath") {`chmod -R a+rw \"$targetppath\"`;}
  if ($debug) {$output .= $debug."\n"}}
unless (-d $webpath)
  {$debug = `$mkwp`;
   if (-d $webpath) {`chmod -R a+rw \"$webpath\"`;}
  if ($debug) {$output .= $debug."\n"}}
    
if($fileType == 25)
	{# Make temp pyramid image
  unless (-e $tmpPyr)
		{`$cmd1`;}
				
  if (-e "$tmpPyr")
    {
    my @temp = ();
	  @temp = `tiffinfo \"$tmpPyr\"  | grep \"Width\"`;

    # Enter pixel width(225) and pixel height(227)
		if ($temp[0] =~ /^.+Image[ ]Width:[ ]+([0-9]+)[ ]+Image[ ]Length:[ ]+([0-9]+)/)
			{$pixelWidth = $1;
			 $pixelHeight = $2;}
		else
			{}
				 
		$pyrLevels = @temp/2;	

    @temp = `tiffinfo \"$tmpPyr\"  | grep \"Bits\"`;
 
    # Enter bit depth (5)
			if ($temp[0] =~ /^.+[:][ ]([0-9]+)/)
			  {$bitDepth = getCatID ($1);}     
    }
	else
		{$output .= "array('Bad PYR, upload failed');";}
		
	if ($pixelWidth) #real image good pyramid
		{
		# Move tmp image and pyramid to /pics/tmp ....
		`$cmd2`;
		`$cmd3`;
		`$cmd4`;
		}
	}
else
	{	
	`$cmd2`;
	`$cmd4`;
	`$cmd5`;	
	}

if (-e "$targetpyramid") {
#if (-e "$tmpPyr") {
	$output .= 'array(
	"fileName" => "'.$name.$suffix.'", 
	"identifier" => "'.$name.'", 
	"fileSize" => '.$fileSize.', 
	"fileFormat" => '.$fileFormat.',
	"pixelWidth" => '.$pixelWidth.', 
	"pixelHeight" => '.$pixelHeight.', 
	"bitDepth" => '.$bitDepth.', 
	"pyrLevels" => '.$pyrLevels.', 
	"targetpath" => "'.$targetpath.'", 
	"targetppath" => "'.$targetppath.'", 
	"targetfile" => "'.$targetfile.'", 
	"targetpyramid" => "'.$targetpyramid.'");';
	}
elsif ((-e "$targetfile"	) && $fileType == 26)
	{
	$output .= 'array(
	"fileName" => "'.$name.$suffix.'", 
	"identifier" => "'.$name.'", 
	"fileSize" => '.$fileSize.', 
	"fileFormat" => '.$fileFormat.',
	"targetpath" => "'.$targetpath.'",  
	"webpath" => "'.$webpath.'",  
	"targetfile" => "'.$targetfile.'",
	"cmd5" => \''.$cmd5.'\');';
	}
else {$output .= "array('Bad Image, upload failed');";}

`rm $img`;
`rm $tmpPyr`;

print $output;
  
